==> base_aux-0.2.25.tar.gz: base_aux-0.2.25/base_aux/testplans/test__tc.py <==
import pytest

from base_aux.testplans.devices import *


# =====================================================================================================================
class DevicesBreeder_Example(DevicesBreeder_WithDut):
    """
    JUST an example DUT+some other single dev
    """
    # DEFINITIONS ---------------
    COUNT: int = 2
    CLS_SINGLE__ATC: type[DeviceBase] = DeviceBase

    # JUST SHOW NAMES -----------
    ATC: DeviceBase


# =====================================================================================================================
class Test__TC:
    @classmethod
    def setup_class(cls):
        pass
        cls.Victim = Base_TestCase

    # @classmethod
    # def teardown_class(cls):
    #     pass
    #
    # def setup_method(self, method):
    #     passtest__tc.py
    #
    # def teardown_method(self, method):
    #     pass

    # -----------------------------------------------------------------------------------------------------------------
    def test__cls(self):
        # EXISTS IN CLS --------------
        assert self.Victim.TCS__LIST == []
        assert self.Victim.DEVICES__BREEDER_CLS is None

        assert self.Victim.result__startup_cls is None
        assert self.Victim.result__teardown_cls is None

        # EXISTS IN INSTANCE --------------
        assert not hasattr(self.Victim, "INDEX")
        # assert not hasattr(self.Victim, "SETTINGS")
        assert not hasattr(self.Victim, "DEVICES__BREEDER_INST")

        assert not hasattr(self.Victim, "timestamp_start")
        assert not hasattr(self.Victim, "details")
        assert not hasattr(self.Victim, "exx")
        assert not hasattr(self.Victim, "progress")

    def test__cls__devices_apply__NONE(self):
        self.Victim.devices__apply()
        assert self.Victim.TCS__LIST == []

        # EXISTS IN CLS --------------
        assert self.Victim.TCS__LIST == []
        assert self.Victim.DEVICES__BREEDER_CLS is None

        assert self.Victim.result__startup_cls is None
        assert self.Victim.result__teardown_cls is None

        # EXISTS IN INSTANCE --------------
        assert not hasattr(self.Victim, "INDEX")
        # assert not hasattr(self.Victim, "SETTINGS")
        assert not hasattr(self.Victim, "DEVICES__BREEDER_INST")

        assert not hasattr(self.Victim, "timestamp_start")
        assert not hasattr(self.Victim, "details")
        assert not hasattr(self.Victim, "exx")
        assert not hasattr(self.Victim, "progress")

    def test__cls__devices_apply__example(self):
        self.Victim.DEVICES__BREEDER_CLS = DevicesBreeder_Example
        self.Victim.devices__apply()

        # EXISTS IN CLS --------------
        assert self.Victim.TCS__LIST != []
        assert self.Victim.DEVICES__BREEDER_CLS is not None

        assert self.Victim.result__startup_cls is None
        assert self.Victim.result__teardown_cls is None

        # EXISTS IN INSTANCE --------------
        assert not hasattr(self.Victim, "INDEX")
        # assert not hasattr(self.Victim, "SETTINGS")
        assert not hasattr(self.Victim, "DEVICES__BREEDER_INST")

        assert not hasattr(self.Victim, "timestamp_start")
        assert not hasattr(self.Victim, "details")
        assert not hasattr(self.Victim, "exx")
        assert not hasattr(self.Victim, "progress")

    # -----------------------------------------------------------------------------------------------------------------
    def test__inst(self):
        self.Victim.DEVICES__BREEDER_CLS = DevicesBreeder_Example
        self.Victim.devices__apply()

        # EXISTS IN CLS --------------
        assert self.Victim.TCS__LIST != []
        assert len(self.Victim.TCS__LIST) == self.Victim.DEVICES__BREEDER_CLS.COUNT

        assert self.Victim(0) is self.Victim.TCS__LIST[0]







        # TODO: FINISH!
        # TODO: FINISH!
        # TODO: FINISH!
        # TODO: FINISH!
        # TODO: FINISH!


# =====================================================================================================================

==> base_aux-0.3.1.1.1.tar.gz: base_aux-0.3.1.1.1/base_aux/testplans/test__tc.py <==
import pytest

from base_aux.testplans.devices import *
from base_aux.testplans.tc import *


# =====================================================================================================================
class Victim_DevicesLines(DeviceKit):
    ATC: TableLine = TableLine(Base_Device)


# =====================================================================================================================
@pytest.mark.skip    # FIXME: ref or not!
class Test__TC:
    @classmethod
    def setup_class(cls):
        pass
        cls.Victim = Base_TestCase

    # @classmethod
    # def teardown_class(cls):
    #     pass
    #
    # def setup_method(self, method):
    #     passtest__tc.py
    #
    # def teardown_method(self, method):
    #     pass

    # -----------------------------------------------------------------------------------------------------------------
    def test__cls(self):
        # EXISTS IN CLS --------------
        assert len(self.Victim.TCSi_LINE) == 0
        assert self.Victim.STAND.DEV_LINES is None

        assert self.Victim.result__startup_cls is None
        assert self.Victim.result__teardown_cls is None

        # EXISTS IN INSTANCE --------------
        assert not hasattr(self.Victim, "INDEX")
        # assert not hasattr(self.Victim, "SETTINGS")
        assert hasattr(self.Victim, "DEV_COLUMN")

        assert not hasattr(self.Victim, "details")
        assert not hasattr(self.Victim, "exx")

    def test__cls__devices_apply__NONE(self):
        assert len(self.Victim.TCSi_LINE) == 0

        # EXISTS IN CLS --------------
        assert self.Victim.STAND.DEV_LINES is None

        assert self.Victim.result__startup_cls is None
        assert self.Victim.result__teardown_cls is None

        # EXISTS IN INSTANCE --------------
        assert not hasattr(self.Victim, "INDEX")
        # assert not hasattr(self.Victim, "SETTINGS")
        assert hasattr(self.Victim, "DEV_COLUMN")

        assert not hasattr(self.Victim, "details")
        assert not hasattr(self.Victim, "exx")

    def test__cls__devices_apply__example(self):
        assert len(self.Victim.TCSi_LINE) == 0
        self.Victim.STAND.DEV_LINES = Victim_DevicesLines()

        # EXISTS IN CLS --------------
        assert self.Victim.STAND.DEV_LINES is not None

        assert self.Victim.result__startup_cls is None
        assert self.Victim.result__teardown_cls is None

        # EXISTS IN INSTANCE --------------
        assert not hasattr(self.Victim, "INDEX")
        # assert not hasattr(self.Victim, "SETTINGS")
        assert hasattr(self.Victim, "DEV_COLUMN")

        assert not hasattr(self.Victim, "details")
        assert not hasattr(self.Victim, "exx")

    # -----------------------------------------------------------------------------------------------------------------
    def test__inst(self):
        self.Victim.STAND.DEV_LINES = Victim_DevicesLines()

        # EXISTS IN CLS --------------
        assert len(self.Victim.TCSi_LINE) == self.Victim.STAND.DEV_LINES.COUNT_COLUMNS

        # assert self.Victim(0) is self.Victim.TCSi_LINE[0]


        # TODO: FINISH!
        # TODO: FINISH!
        # TODO: FINISH!
        # TODO: FINISH!
        # TODO: FINISH!


# =====================================================================================================================
